==> harpo-2.0.0.tar.gz: CHANGELOG.md <==
# CHANGELOG

## Version 1.0.0: Beta release

- added documentation
- initial upload to GitHub
- initial version


## Version 1.0.1: Initial release

- added a test project
- added some more usage documentation
- added a test app
- fixed a bug

## Version 1.0.2: Binary update

- added binary conversion functions
- overhauled code to conform with `pedantic`
- added a `SUPPORT ME` link

## Version 1.0.3: Documentation update

- added doc comments
- changed doc structure

## Version 1.0.4: Documentation update: code formatting

- formatted code according to pub.dev
- minor fixes

## Version 1.0.5: Documentation update: updated docs

- correction of docs
- more comments
- minor fixes

## Version 1.1.0: The Big Binary Update

- all encryption/decryption functions ported to use binary
- additional API for this is available in `lib/binary.dart`
- minor fixes
- more docs

## Version 1.1.1: The Big Binary Update Documentation

- updated the documentation with all new methods
- better layout of `harpo/binary.dart`
- minor fixes

## Version 1.1.2: MinUp Update Part I

- removed the `SUPPORT ME` section
- moved code to another repo
- changed my username and GitHub account

## Version 1.1.3: MinUp Update Part II

- updated documentation
- minor fixes

## Version 1.1.4: MinUp Update Part III

- updated documentation
- updated example

## Version 1.1.5: Null Safety Update!

- minor fixes
- organized code better
- NULL SAFETY

## Version 1.1.6-nullsafety.0: Null Safety Update Pt. I

- minor fixes
- optimization
- is in line with *Pub.dev's* policies

## Version 1.1.7-nullsafety.0: Null Safety Update Pt. II

- minor fixes
- code optimizations
- better code tests

## Version 1.2.0-nullsafety.0: Milestone update

- minor fixes
- updated documentation

## Version 2.0.0: Hexadecimal Update!

- minor improvements
- conversion from hex numbers to decimal numbers
- speed improvements

==> harpo-2.2.0.tar.gz: CHANGELOG.md <==
# CHANGELOG

## Version 1.0.0: Beta release

- added documentation
- initial upload to GitHub
- initial version


## Version 1.0.1: Initial release

- added a test project
- added some more usage documentation
- added a test app
- fixed a bug

## Version 1.0.2: Binary update

- added binary conversion functions
- overhauled code to conform with `pedantic`
- added a `SUPPORT ME` link

## Version 1.0.3: Documentation update

- added doc comments
- changed doc structure

## Version 1.0.4: Documentation update: code formatting

- formatted code according to pub.dev
- minor fixes

## Version 1.0.5: Documentation update: updated docs

- correction of docs
- more comments
- minor fixes

## Version 1.1.0: The Big Binary Update

- all encryption/decryption functions ported to use binary
- additional API for this is available in `lib/binary.dart`
- minor fixes
- more docs

## Version 1.1.1: The Big Binary Update Documentation

- updated the documentation with all new methods
- better layout of `harpo/binary.dart`
- minor fixes

## Version 1.1.2: MinUp Update Part I

- removed the `SUPPORT ME` section
- moved code to another repo
- changed my username and GitHub account

## Version 1.1.3: MinUp Update Part II

- updated documentation
- minor fixes

## Version 1.1.4: MinUp Update Part III

- updated documentation
- updated example

## Version 1.1.5: Null Safety Update!

- minor fixes
- organized code better
- NULL SAFETY

## Version 1.1.6-nullsafety.0: Null Safety Update Pt. I

- minor fixes
- optimization
- is in line with *Pub.dev's* policies

## Version 1.1.7-nullsafety.0: Null Safety Update Pt. II

- minor fixes
- code optimizations
- better code tests

## Version 1.2.0-nullsafety.0: Milestone update

- minor fixes
- updated documentation

## Version 2.0.0: Hexadecimal Update Pt. I

- minor improvements
- conversion from hex numbers to decimal numbers
- speed improvements

## Version 2.1.0: Hexadecimal Update Pt. II

- minor fixes
- pedantic fix

## Version 2.2.0: The Hexadecimal Update

- added a function to convert base 10 numbers into hexadecimal numbers
- added the corresponding encryption/decryption functions
- minor polishes here and there
